#!/usr/bin/python3
import argparse
from PIL import Image

parser = argparse.ArgumentParser(description='Stretch INPUT by copying the column at index START over all subsequent ones.')
parser.add_argument('input',
                    action = 'store',
                    metavar = 'INPUT',
                    help = 'Path to the input image.')

parser.add_argument('start',
                    action = 'store',
                    metavar = 'START',
                    type = int,
                    help = 'Index at which to start stretching.')

parser.add_argument('output',
                    action = 'store',
                    metavar = 'OUTPUT',
                    help = 'Path at which to store result.')

parser.add_argument('-v', '--vertical',
                    action = 'store_true',
                    help = 'Stretch vertically instead of horizontally.')

parser.add_argument('-i', '--invert',
                    action = 'store_true',
                    help = 'Overwrite all previous lines instead of the subsequent ones.')

if __name__ == '__main__':
    args = parser.parse_args()

    try:
        img = Image.open(args.input)
    except:
        print('Could not open image file {}.'.format(args.input))

    width, height = img.size
    size = height if args.vertical else width

    try:
        assert args.start < size
    except:
        dim = 'height' if args.vertical else 'width'
        print('Starting index is larger than the image\'s {}.'.format(dim))

    slit = lambda i : (0, i, width, i + 1) if args.vertical else (i, 0, i + 1, height)
    strip = img.crop(slit(args.start))
    indices = range(0, args.start) if args.invert else range(args.start, size)

    for i in indices:
        img.paste(strip, slit(i))

    img.save(args.output)
